import type { Home } from './types/Home';
export type DirigeraClient = Awaited<ReturnType<typeof createDirigeraClient>>;
export type { AirPurifier } from './types/device/AirPurifier';
export type { Blinds } from './types/device/Blinds';
export type { Capabilities } from './types/Capabilities';
export type { Controller } from './types/device/Controller';
export type { Device } from './types/device/Device';
export type { DeviceSet } from './types/DeviceSet';
export type { EnvironmentSensor } from './types/device/EnvironmentSensor';
export type { Home } from './types/Home';
export type { Hub } from './types/device/Hub';
export type { Light } from './types/device/Light';
export type { MotionSensor } from './types/device/MotionSensor';
export type { Music } from './types/Music';
export type { OpenCloseSensor } from './types/device/OpenCloseSensor';
export type { Outlet } from './types/device/Outlet';
export type { Repeater } from './types/device/Repeater';
export type { Room } from './types/Room';
export type { Scene } from './types/Scene';
export type { Speaker } from './types/device/Speaker';
export type { User } from './types/User';
export declare function createDirigeraClient({ gatewayIP, accessToken, }: {
    gatewayIP?: string;
    accessToken?: string;
}): Promise<{
    authenticate(): Promise<string>;
    home(): Promise<Home>;
    hub: {
        status(): Promise<import("./types/device/Hub").Hub>;
        checkFirmwareUpdate(): Promise<void>;
        installFirmwareUpdate(): Promise<void>;
    };
    devices: {
        list(): Promise<import("./types/device/Device").Device[]>;
        get({ id }: {
            id: string;
        }): Promise<import("./types/device/Device").Device>;
        setCustomName({ id, customName, }: {
            id: string;
            customName: string;
        }): Promise<void>;
        setAttributes({ id, attributes, transitionTime, }: {
            id: string;
            attributes: Partial<import("./types/device/Device").CommonDeviceAttributes & Partial<import("./types/device/Device").IdentifiableDeviceAttributes> & Partial<import("./types/device/Device").JoinableDeviceAttributes> & Partial<import("./types/device/Device").OtaUpdatableDeviceAttributes> & Partial<import("./types/device/AirPurifier").AirPurifierAttributes> & Partial<import("./types/device/Blinds").BlindsAttributes> & Partial<import("./types/device/Controller").ControllerAttributes> & Partial<import("./types/device/EnvironmentSensor").EnvironmentSensorAttributes> & Partial<import("./types/device/Hub").HubAttributes> & Partial<import("./types/device/Light").LightAttributes> & Partial<import("./types/device/MotionSensor").MotionSensorAttributes> & Partial<import("./types/device/OpenCloseSensor").OpenCloseSensorAttributes> & Partial<import("./types/device/Outlet").OutletAttributes> & Partial<import("./types/device/Repeater").RepeaterAttributes> & Partial<import("./types/device/Speaker").SpeakerAttributes>>;
            transitionTime?: number;
        }): Promise<void>;
    };
    lights: {
        list(): Promise<import("./types/device/Light").Light[]>;
        get({ id }: {
            id: string;
        }): Promise<import("./types/device/Light").Light>;
        setIsOn({ id, isOn }: {
            id: string;
            isOn: boolean;
        }): Promise<void>;
        setLightLevel({ id, lightLevel, transitionTime, }: {
            id: string;
            lightLevel: number;
            transitionTime?: number;
        }): Promise<void>;
        setLightTemperature({ id, colorTemperature, transitionTime, }: {
            id: string;
            colorTemperature: number;
            transitionTime?: number;
        }): Promise<void>;
        setLightColor({ id, colorHue, colorSaturation, transitionTime, }: {
            id: string;
            colorHue: number;
            colorSaturation: number;
            transitionTime?: number;
        }): Promise<void>;
    };
    outlets: {
        list(): Promise<import("./types/device/Outlet").Outlet[]>;
        get({ id }: {
            id: string;
        }): Promise<import("./types/device/Outlet").Outlet>;
        setIsOn({ id, isOn }: {
            id: string;
            isOn: boolean;
        }): Promise<void>;
    };
    controllers: {
        list(): Promise<import("./types/device/Controller").Controller[]>;
        get({ id }: {
            id: string;
        }): Promise<import("./types/device/Controller").Controller>;
    };
    speakers: {
        list(): Promise<import("./types/device/Speaker").Speaker[]>;
        get({ id }: {
            id: string;
        }): Promise<import("./types/device/Speaker").Speaker>;
        setVolume({ id, volume }: {
            id: string;
            volume: number;
        }): Promise<void>;
        setPlayback({ id, playback, }: {
            id: string;
            playback: "playbackIdle" | "playbackPlaying" | "playbackPaused" | "playbackNext" | "playbackPrevious" | "playbackBuffering";
        }): Promise<void>;
    };
    blinds: {
        list(): Promise<import("./types/device/Blinds").Blinds[]>;
        get({ id }: {
            id: string;
        }): Promise<import("./types/device/Blinds").Blinds>;
        setCurrentLevel({ id, blindsCurrentLevel, }: {
            id: string;
            blindsCurrentLevel: number;
        }): Promise<void>;
        setTargetLevel({ id, blindsTargetLevel, }: {
            id: string;
            blindsTargetLevel: number;
        }): Promise<void>;
        setState({ id, blindsState, }: {
            id: string;
            blindsState: "stopped" | "up" | "down";
        }): Promise<void>;
    };
    airPurifiers: {
        list(): Promise<import("./types/device/AirPurifier").AirPurifier[]>;
        get({ id }: {
            id: string;
        }): Promise<import("./types/device/AirPurifier").AirPurifier>;
        setFanMode({ id, fanMode, }: {
            id: string;
            fanMode: "auto" | "manual" | "off";
        }): Promise<void>;
        setMotorState({ id, motorState, }: {
            id: string;
            motorState: number;
        }): Promise<void>;
        setChildLock({ id, childLock, }: {
            id: string;
            childLock: boolean;
        }): Promise<void>;
        setStatusLight({ id, statusLight, }: {
            id: string;
            statusLight: boolean;
        }): Promise<void>;
    };
    repeaters: {
        list(): Promise<import("./types/device/Repeater").Repeater[]>;
        get({ id }: {
            id: string;
        }): Promise<import("./types/device/Repeater").Repeater>;
    };
    motionSensors: {
        list(): Promise<import("./types/device/MotionSensor").MotionSensor[]>;
        get({ id }: {
            id: string;
        }): Promise<import("./types/device/MotionSensor").MotionSensor>;
        setOnDuration({ id, onDuration, }: {
            id: string;
            onDuration: number;
        }): Promise<void>;
        setScheduleOn({ id, scheduleOn, }: {
            id: string;
            scheduleOn: boolean;
        }): Promise<void>;
        setSchedule({ id, schedule, }: {
            id: string;
            schedule: {
                onCondition: {
                    time: string;
                };
                offCondition: {
                    time: string;
                };
            };
        }): Promise<void>;
    };
    environmentSensors: {
        list(): Promise<import("./types/device/EnvironmentSensor").EnvironmentSensor[]>;
        get({ id }: {
            id: string;
        }): Promise<import("./types/device/EnvironmentSensor").EnvironmentSensor>;
    };
    openCloseSensors: {
        list(): Promise<import("./types/device/OpenCloseSensor").OpenCloseSensor[]>;
        get({ id }: {
            id: string;
        }): Promise<import("./types/device/OpenCloseSensor").OpenCloseSensor>;
    };
    deviceSets: {
        list(): Promise<import("./types/DeviceSet").DeviceSet[]>;
        setIsOn({ id, isOn }: {
            id: string;
            isOn: boolean;
        }): Promise<void>;
        setAttributes({ id, attributes, transitionTime, }: {
            id: string;
            attributes: Partial<import("./types/device/Device").CommonDeviceAttributes & Partial<import("./types/device/Device").IdentifiableDeviceAttributes> & Partial<import("./types/device/Device").JoinableDeviceAttributes> & Partial<import("./types/device/Device").OtaUpdatableDeviceAttributes> & Partial<import("./types/device/AirPurifier").AirPurifierAttributes> & Partial<import("./types/device/Blinds").BlindsAttributes> & Partial<import("./types/device/Controller").ControllerAttributes> & Partial<import("./types/device/EnvironmentSensor").EnvironmentSensorAttributes> & Partial<import("./types/device/Hub").HubAttributes> & Partial<import("./types/device/Light").LightAttributes> & Partial<import("./types/device/MotionSensor").MotionSensorAttributes> & Partial<import("./types/device/OpenCloseSensor").OpenCloseSensorAttributes> & Partial<import("./types/device/Outlet").OutletAttributes> & Partial<import("./types/device/Repeater").RepeaterAttributes> & Partial<import("./types/device/Speaker").SpeakerAttributes>>;
            transitionTime?: number;
        }): Promise<void>;
    };
    rooms: {
        list(): Promise<import("./types/Room").Room[]>;
        get({ id }: {
            id: string;
        }): Promise<import("./types/Room").Room>;
        setIsOn({ id, deviceType, isOn, }: {
            id: string;
            deviceType: "airPurifier" | "blinds" | "gateway" | "light" | "outlet" | "repeater" | "speaker" | "environmentSensor" | "shortcutController" | "lightController" | "soundController" | "blindsController" | "motionSensor" | "openCloseSensor";
            isOn: boolean;
        }): Promise<void>;
        setAttributes({ id, deviceType, attributes, transitionTime, }: {
            id: string;
            deviceType?: "airPurifier" | "blinds" | "gateway" | "light" | "outlet" | "repeater" | "speaker" | "environmentSensor" | "shortcutController" | "lightController" | "soundController" | "blindsController" | "motionSensor" | "openCloseSensor";
            attributes: Partial<import("./types/device/Device").CommonDeviceAttributes & Partial<import("./types/device/Device").IdentifiableDeviceAttributes> & Partial<import("./types/device/Device").JoinableDeviceAttributes> & Partial<import("./types/device/Device").OtaUpdatableDeviceAttributes> & Partial<import("./types/device/AirPurifier").AirPurifierAttributes> & Partial<import("./types/device/Blinds").BlindsAttributes> & Partial<import("./types/device/Controller").ControllerAttributes> & Partial<import("./types/device/EnvironmentSensor").EnvironmentSensorAttributes> & Partial<import("./types/device/Hub").HubAttributes> & Partial<import("./types/device/Light").LightAttributes> & Partial<import("./types/device/MotionSensor").MotionSensorAttributes> & Partial<import("./types/device/OpenCloseSensor").OpenCloseSensorAttributes> & Partial<import("./types/device/Outlet").OutletAttributes> & Partial<import("./types/device/Repeater").RepeaterAttributes> & Partial<import("./types/device/Speaker").SpeakerAttributes>>;
            transitionTime?: number;
        }): Promise<void>;
    };
    scenes: {
        list(): Promise<import("./types/Scene").Scene[]>;
        get({ id }: {
            id: string;
        }): Promise<import("./types/Scene").Scene>;
        trigger({ id }: {
            id: string;
        }): Promise<void>;
        undo({ id }: {
            id: string;
        }): Promise<void>;
    };
    music: {
        get(): Promise<import("./types/Music").Music>;
    };
    users: {
        list(): Promise<import("./types/User").User[]>;
        getCurrentUser(): Promise<import("./types/User").User>;
        setCurrentUserName({ name }: {
            name: string;
        }): Promise<void>;
        delete({ id }: {
            id: string;
        }): Promise<void>;
    };
    startListeningForUpdates(callback: (updateEvent: any) => void): void;
    stopListeningForUpdates(): void;
}>;
